<template>
  <div>
    <!-- 列表页面 -->
    <div class="page-container" v-if="showEdit == 0">
      <!-- 查询条件 -->
      <div class="search-section">
        <el-form :inline="true" :model="queryForm" class="demo-form-inline" label-width="auto">
          <el-form-item label="项目关键字">
            <el-input v-model="queryForm.keyword" placeholder="名称/描述/备注/项目经理/联系人" clearable />
          </el-form-item>
          <el-form-item label="项目类型">
            <el-select v-model="queryForm.type" placeholder="类型" clearable filterable>
              <el-option v-for="item in projectTypeArr" :key="item.value" :label="item.label" :value="item.value" />
            </el-select>
          </el-form-item>
          <el-form-item label="项目阶段">
            <el-select v-model="queryForm.stage" placeholder="阶段" clearable filterable>
              <el-option v-for="item in projectStageArr" :key="item.value" :label="item.label" :value="item.value" />
            </el-select>
          </el-form-item>
          <el-form-item label="项目状态">
            <el-select v-model="queryForm.status" placeholder="类型" clearable filterable>
              <el-option v-for="item in projectStatusArr" :key="item.value" :label="item.label" :value="item.value" />
            </el-select>
          </el-form-item>
          <el-form-item>
            <el-button type="primary" @click="search">查询</el-button>
            <el-button type="primary" @click="add">新增</el-button>
          </el-form-item>
        </el-form>
      </div>
      <!-- 表格 -->
      <div class="table-section">
        <el-table
          row-key="id"
          default-expand-all
          :data="tableData"
          v-loading="loading"
          style="width: 100%"
          height="450px"
        >
          <el-table-column prop="name" label="名称" fixed="left"></el-table-column>

          <el-table-column label="操作栏" fixed="right" width="200">
            <template #default="scope">
              <el-button type="text" size="small" @click="handleChildEdit(scope.row)">子节点</el-button>
              <el-button v-if="scope.row.project_flag != 1" type="text" size="small" @click="handleEdit(scope.row)"
                >编辑</el-button
              >
              <el-button v-if="scope.row.project_flag != 1" type="text" size="small" @click="handleDelete(scope.row)"
                >删除</el-button
              >
            </template>
          </el-table-column>
        </el-table>

        <div class="demo-pagination-block">
          <!-- <div class="demonstration">All combined</div> -->
          <el-pagination
            v-model:current-page="currentPage"
            v-model:page-size="pageSize"
            :page-sizes="[10, 20, 30]"
            :small="small"
            :disabled="disabled"
            :background="background"
            layout="total, sizes, prev, pager, next, jumper"
            :total="totalSize"
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
          />
        </div>
      </div>
    </div>
    <!-- 编辑页面 -->
    <project-module-add
      v-if="showEdit == 1"
      @editClose="editClose"
      :editId="editId"
      :parentId="parentId"
    ></project-module-add>
  </div>
</template>

<script>
import { ref, reactive, onMounted } from 'vue'
import { ElMessageBox, ElMessage } from 'element-plus'

// import ProjectModuleInfo from '@/model/ProjectModuleInfo'
import sysDictItemModel from '@/model/sysDictItem'

import ProjectModuleAdd from '@/view/project-module/project-module-add'
import ProjectSetUp from '@/view/project/project-set-up'
import ProjectEditHours from '@/view/project/project-edit-hours'
import ProjectLog from '@/view/project/project-log'
import projectHourStatistics from '@/view/project/project-hour-statistics'
import projectDetail from '@/view/project/project-detail'

import ProjectModuleInfo from '@/model/projectModuleInfo'

export default {
  components: {
    ProjectModuleAdd,
    ProjectSetUp,
    ProjectEditHours,
    ProjectLog,
    projectHourStatistics,
    projectDetail,
  },

  setup() {
    const loading = ref(false)

    const currentPage = ref(1)
    const pageSize = ref(10)
    const totalSize = ref(100)
    const projectTypeArr = ref([])
    const projectStatusArr = ref([])
    const projectStageArr = ref([])

    const showEdit = ref(0)
    const editId = ref(1)
    const parentId = ref(1)

    const queryForm = reactive({
      keyword: '',
      type: '',
      stage: '',
      status: '',

      page: 1,
      count: 10,
    })

    const resultPage = ref({})

    const tableData = ref([])

    onMounted(() => {
      // 列出所有项目信息
      getPage()
      loadDictDitems()
    })

    const getPage = async () => {
      try {
        
        queryForm.page = currentPage.value
        queryForm.count = pageSize.value

        loading.value = true
        resultPage.value = await ProjectModuleInfo.getProjectModuleInfoPage(queryForm)
        console.log(resultPage.value)
        tableData.value = resultPage.value.items
        totalSize.value = resultPage.value.total
        currentPage.value = resultPage.value.page
        pageSize.value = resultPage.value.count

        loading.value = false
      } catch (error) {
        console.log(error)
        loading.value = false
        if (error.code === 10020) {
          tableData.value = []
        }
      }
    }

    const search = () => {
      // 执行查询操作，更新表格数据
      // 列出所有项目信息
      getPage()
    }

    // 根据字典类型查询字典
    const loadDictDitems = async () => {
      projectTypeArr.value = await sysDictItemModel.getSysDictItemListByType('project_type')
      projectStatusArr.value = await sysDictItemModel.getSysDictItemListByType('project_status')
      projectStageArr.value = await sysDictItemModel.getSysDictItemListByType('project_stage')
    }

    const handleEdit = row => {
      // 编辑操作
      editId.value = row.id
      showEdit.value = 1
    }

    const handleChildEdit = row => {
      
      // 编辑操作
      editId.value = ''
      parentId.value = row.id
      if (row.project_flag == 1) {
        parentId.value = row.id
      }
      showEdit.value = 1
    }

    const handleDelete = row => {
      // 删除操作
      ElMessageBox.confirm('此操作将永久删除该记录, 是否继续?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
        .then(async () => {
          const res = await ProjectModuleInfo.deleteProjectModuleInfo(row.id)
          if (res.code < window.MAX_SUCCESS_CODE) {
            getPage()
            ElMessage.success(`${res.message}`)
          }
        })
        .catch(() => {
          // 用户点击取消按钮时执行的操作
          // 可以选择不做任何事情，也可以显示取消消息
          // ElMessage.info('操作已取消'); // 如果需要显示取消消息，可以取消注释
        })
    }

    /**
     * 项目立项
     */
    const handleProjectSetUp = row => {
      // 工时确认操作
      editId.value = row.id
      showEdit.value = 2
    }

    /**
     * 项目启动
     */
    const handleProjectStart = row => {
      ElMessageBox.confirm('确定启动项目, 是否继续?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
        .then(async () => {
          const res = await ProjectModuleInfo.editProjectInfoStart(row.id)
          if (res.code < window.MAX_SUCCESS_CODE) {
            getPage()
            ElMessage.success(`${res.message}`)
          }
        })
        .catch(() => {
          // 用户点击取消按钮时执行的操作
          // 可以选择不做任何事情，也可以显示取消消息
          // ElMessage.info('操作已取消'); // 如果需要显示取消消息，可以取消注释
        })
    }

    /**
     * 项目完成
     */
    const handleProjectComplete = row => {
      ElMessageBox.confirm('确定完成项目, 是否继续?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
        .then(async () => {
          const res = await ProjectModuleInfo.editProjectInfoComplete(row.id)
          if (res.code < window.MAX_SUCCESS_CODE) {
            getPage()
            ElMessage.success(`${res.message}`)
          }
        })
        .catch(() => {
          // 用户点击取消按钮时执行的操作
          // 可以选择不做任何事情，也可以显示取消消息
          // ElMessage.info('操作已取消'); // 如果需要显示取消消息，可以取消注释
        })
    }

    /**
     * 项目终止
     */
    const handleProjectTermination = row => {
      ElMessageBox.confirm('确定终止项目, 是否继续?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
        .then(async () => {
          const res = await ProjectModuleInfo.editProjectInfoTermination(row.id)
          if (res.code < window.MAX_SUCCESS_CODE) {
            getPage()
            ElMessage.success(`${res.message}`)
          }
        })
        .catch(() => {
          // 用户点击取消按钮时执行的操作
          // 可以选择不做任何事情，也可以显示取消消息
          // ElMessage.info('操作已取消'); // 如果需要显示取消消息，可以取消注释
        })
    }

    /**
     * 查看项目日志
     */
    const handleProjectLog = row => {
      // 工时操作
      editId.value = row.id
      showEdit.value = 4
    }

    /**
     * 查看项目统计
     */
    const handleProjectStatistics = row => {
      // 工时操作
      editId.value = row.id
      showEdit.value = 5
    }

    const handleProjectHours = row => {
      // 工时操作
      editId.value = row.id
      showEdit.value = 3
    }

    const handleSizeChange = val => {
      pageSize.value = val
      getPage()
    }

    const handleCurrentChange = val => {
      currentPage.value = val
      getPage()
    }

    const editClose = () => {
      showEdit.value = 0
      getPage()
    }

    const add = () => {
      showEdit.value = 1
      editId.value = ''
    }

    return {
      loading,

      projectTypeArr,
      projectStatusArr,
      projectStageArr,

      queryForm,
      tableData,
      search,
      handleEdit,
      handleChildEdit,
      handleDelete,
      handleProjectSetUp,
      handleProjectStart,
      handleProjectComplete,
      handleProjectTermination,
      handleProjectHours,
      handleProjectLog,
      handleProjectStatistics,

      currentPage,
      pageSize,
      totalSize,

      handleSizeChange,
      handleCurrentChange,

      editClose,
      add,
      editId,
      parentId,
      showEdit,
    }
  },
}
</script>

<style scoped>
.demo-form-inline .el-input {
  --el-input-width: 220px;
}

.page-container {
  padding: 10px;
}

.search-section {
  margin-bottom: 10px;
  padding: 20px;
  /* background-color: #f5f5f5; */
  border-radius: 4px;
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
}

.table-section {
  padding: 20px;
  background-color: #fff;
  border-radius: 4px;
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
}
.demo-pagination-block {
  margin-top: 10px;
}
.demo-pagination-block .demonstration {
  margin-bottom: 16px;
}

.icon_btn_class {
  width: 1em;
  height: 1em;
  margin-left: 4px;
  margin-right: 4px;
}

.el-form-item {
  width: 220px;
}
</style>
